/*
 * An implementation of the SHA-256 hash function, this is endian neutral
 * so should work just about anywhere.
 *
 * This code works much like the MD5 code provided by RSA.  You sha256_init()
 * a "sha256_state" then sha256_process() the bytes you want and sha256_done() to get
 * the output.
 *
 * Revised Code:  Complies to SHA-256 standard now.
 *
 * Tom St Denis, Oct 12th 2000
 * Disastry, Aug 30th 2001, (self test)
 * Disastry, Jan 16th 2002, (64 bit length)
 * Disastry, Apr 22th 2002 ("off-by-one" bug fixed (output was wrong for length = 55 + 64 * n , where n = 0,1,2,3,...)
 * */

#include "usuals.h"  /* typedefs for byte, word16, boolean, etc. */
#define UINT32 word32

typedef struct {
	unsigned long state[8], length0, length1, curlen;
	unsigned char buf[64];
} sha_state;


void sha_init(sha_state *md);
void sha_process(sha_state *md, unsigned char *buf, unsigned len);
void sha_done(sha_state *md, unsigned char *hash);

/* sha-256 a block of memory */
void sha_memory(unsigned char *buf, unsigned len, unsigned char *hash);
/* sha-256 a file, return 1 if ok */
int sha_file(char *filename, unsigned char *hash);
